/*****************************************************************
 * FlexDebug.cpp
 * 
 * This file contains the code necessary to write a debugger module
 * for FlexBot. If you are writing a debugger, there is no need to
 * modify this file. All code for the debugger can be placed in
 * the FlexDebug.cpp file.
 *
 * If placed in the FlexDebug directory within the FlexBot directory,
 * this debugging module will receive all debugging messages passed
 * to FlexBot by individual bots. Keep in mind that calls to this
 * debugging module are synchronous (blocking), so it is important
 * to make your FlexDebug module code efficient so as not to adversely
 * impact game performance.
 *****************************************************************/

#include "stdafx.h"
#include <stdio.h>
#include "FlexDebug.h"

/*****************************************************
 * RESET                    					     *
 *													 *
 * This function is called when the game is reset.   *
 * Serves as notification that old bots may no       *
 * longer exist. This might be useful if the		 *
 * debugger presents a list of active bots from      *
 * which to pick one to debug.                       *
 *****************************************************/
FLEXDEBUG_API void Reset(void)
{
	// **** Remove this code for your debugger **** //
	MessageBox(NULL, "Reset() was called.", "Notification", MB_OK);
}


/*****************************************************
 * BOT REMOVED                 					     *
 *													 *
 * This function is called when a bot is removed     *
 * from the game. It serves as notification that the *
 * specified bot may no longer be active in the game *
 * This might be useful if the debugger presents a   *
 * list of active bots.                              *
 *****************************************************/
FLEXDEBUG_API void BotRemoved(int botNum)
{
	// **** Remove this code for your debugger **** //
	MessageBox(NULL, "BotRemoved() was called.", "Notification", MB_OK);
}


/*****************************************************
 * DEBUG MESSAGE               					     *
 *													 *
 * This function is called when a debug message is   *
 * passed to FlexBot from an individual bot. The     *
 * message is not guaranteed to be in any specific   *
 * format, although the de facto standard is:        *
 *   "variable-name variable-value"                  *
 *       e.g. "left-distance 29"                     *
 *            "stuck? FALSE"                         *
 *            "forward-gain 1.37"                    *
 *****************************************************/
FLEXDEBUG_API void DebugMessage(int botNum, const char * msg)
{
	// **** Remove this code for your debugger **** //
	char caption[50];
	sprintf(caption, "Message from bot %d", botNum);
	MessageBox(NULL, msg, caption, MB_OK);
	// ******************************************** //
}

/*****************************************************
 * DLL MAIN                    					     *
 *													 *
 * This function does NOT need to be modified.       *
 * You may use it to execute initialization code     *
 * for your debugger. It is called when the DLL		 *
 * is initially loaded by FlexBot.                   *
 *****************************************************/
BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
    switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
		case DLL_THREAD_ATTACH:
		case DLL_THREAD_DETACH:
		case DLL_PROCESS_DETACH:
			break;
    }
    return TRUE;
}