/*****************************************************************
 * FlexStat.h
 * 
 * This is the header file for the code necessary to write a
 * statistical analysis module for the FlexBot MOD in Half-Life. If
 * you are writing a FlexStat module, there is no need to modify
 * this file. All module-specific code can be placed in the
 * "FlexStat.cpp" file.
 *
 * If placed in the FlexStat directory within the FlexBot directory,
 * this module will have the appropriate functions called when
 * statistical changes occur. All statistics are defined and exported
 * by the central FlexBot architecture. Keep in mind that 
 * calls to this module are synchronous (blocking), so it is
 * important to make your FlexStat module code efficient so as not to
 * adversely impact game performance.
 *****************************************************************/

#ifndef FLEXSTAT_H
#define FLEXSTAT_H

#ifdef FLEXSTAT_EXPORTS
#define FLEXSTAT_API __declspec(dllexport)
#else
#define FLEXSTAT_API __declspec(dllimport)
#endif // FLEXSTAT_EXPORTS

// ------ FlexStat module initialization routines ------ //
bool flex_stat_initialized = false;
void InitFlexStatModule();

// ------ Exported by this FlexStat module ------ //
FLEXSTAT_API void AddPlayer(int);
FLEXSTAT_API void RemovePlayer(int);
FLEXSTAT_API void UpdatePlayerName(int, const char *);
FLEXSTAT_API void UpdatePlayerTeam(int, const char *);
FLEXSTAT_API void UpdateBotBehavior(int, const char *);
FLEXSTAT_API void GameStart();
FLEXSTAT_API void UpdatePlayerStat(int, const char *, const char *);
FLEXSTAT_API void UpdateTeamStat(const char *, const char *, const char *);
FLEXSTAT_API void UpdateGameStat(const char *, const char *);



/*****************************************************
 * DLL MAIN                    					     *
 *													 *
 * This function does NOT need to be modified.       *
 *****************************************************/
BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
    switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
		case DLL_THREAD_ATTACH:
		case DLL_THREAD_DETACH:
		case DLL_PROCESS_DETACH:
			break;
    }

	// Perform any FlexStat module initializations
	if (!flex_stat_initialized) {
		InitFlexStatModule();
		flex_stat_initialized = true;
	}

    return TRUE;
}

#endif // FLEXSTAT_H